@@ -22,7 +22,7 @@
 
 #include "hyantes.h"
 
-#include "hs_compat.h"
+#include "hs_config.h"
 #if defined HAVE_LIBPTHREAD && HAVE_LIBPTHREAD
 #include <pthread.h>
 
@@ -34,7 +34,7 @@ static int display_status(int *sz)
         (void) sleep(1);
     while((curr = hs_status()) < max)
     {
-        fprintf(stdout, "\r#completed task / #total task:%lu/%lu [%d%%] ",
+        fprintf(stdout, "\r# completed task / total task:%lu/%lu [%d%%] ",
            curr, max, (int) (curr * 100 / max));
         if(fflush(stdout) != 0)
         {
@@ -112,13 +112,13 @@ static void print_help(FILE * out)
 
 static int run(int argc, char **argv)
 {
-    size_t i, len;
+    size_t i;
     int resLat = 0, resLon = 0;
     hs_potential_t *pOut = NULL;
-    hs_coord_t visu = { 0.f, 0.f, 0.f, 0.f };
+    hs_coord_t visu = { 0., 0., 0., 0. };
     char *function = NULL;
     const char default_function[] = "disk";
-    double range = 0.f;
+    double range = 0.;
     FILE *fi = NULL, *fo = NULL;
     int do_compute = 1;
 
@@ -131,21 +131,21 @@ static int run(int argc, char **argv)
     char short_options[1 +
        3 * sizeof(long_description) / sizeof(*long_description)];
     {
-        size_t j;
+        size_t k;
         const size_t n =
            sizeof(long_description) / sizeof(*long_description);
-        for(i = 0, j = 0; i < n; i++)
+        for(i = 0, k = 0; i < n; i++)
         {
             if(long_options[i].val > 0)
             {
-                short_options[j++] = long_options[i].name[0];
+                short_options[k++] = long_options[i].name[0];
                 if(long_options[i].has_arg > 0)
-                    short_options[j++] = ':';
+                    short_options[k++] = ':';
                 if(long_options[i].has_arg == 2)
-                    short_options[j++] = ':';
+                    short_options[k++] = ':';
             }
         }
-        short_options[j] = '\0';
+        short_options[k] = '\0';
     }
 
     if(hs_set(HS_MODULE_OPT, &argc, argv) != 0)
@@ -193,6 +193,7 @@ static int run(int argc, char **argv)
                     exit(EXIT_FAILURE);
                 }
             }
+            printf("opening: %s\n", optarg);
             fi = fopen(optarg, "r");
             if(!fi)
             {
@@ -244,7 +245,7 @@ static int run(int argc, char **argv)
             break;
 
         case 't':
-            (void) hs_set(HS_THRESHOLD, optarg);
+            (void) hs_set(HS_THRESHOLD, atof(optarg));
             break;
 
         case 'r':
@@ -358,19 +359,13 @@ static int run(int argc, char **argv)
         (void) hs_set(HS_SMOOTH_FUNC, function, range);
 
     pOut = hs_smooth(resLat, resLon, visu, fi);
+	fclose(fi);
 
-#if HAVE_LIBPTHREAD
-    /*@-usedef@ */
-    if(do_compute == 1 && pthread_join(thread, NULL) != 0)
-    {
-        perror("[pthread_join]");
-        exit(EXIT_FAILURE);
-    }
-#endif
 
     /* catch error */
     if(do_compute == 1)
     {
+        int k,l;
         if(pOut == NULL)
         {
             fprintf(stdout, "# program ended with an error\n");
@@ -379,10 +374,13 @@ static int run(int argc, char **argv)
         }
 
         /* write result on stdout */
-        len = (size_t) (resLat * resLon);
-        for(i = 0; i < len; i++)
-            fprintf(fo, "%f %f %f\n", pOut[i].lat, pOut[i].lon,
-               pOut[i].pot);
+        for(k = 0; k < resLat; k++)
+        {
+            for(l = 0; l < resLon; l++)
+                fprintf(fo, "%lf %lf %lf\n", pOut[k * resLon + l].lat,
+                   pOut[k * resLon + l].lon, pOut[k * resLon + l].pot);
+            fprintf(fo, "\n");
+        }
 
         /* the end */
         free(pOut);
@@ -391,6 +389,14 @@ static int run(int argc, char **argv)
     {
         assert(pOut == NULL);
     }
+#if HAVE_LIBPTHREAD
+    /*@-usedef@ */
+    if(do_compute == 1 && pthread_join(thread, NULL) != 0)
+    {
+        perror("[pthread_join]");
+        exit(EXIT_FAILURE);
+    }
+#endif
 
     if(fclose(fo) != 0)
     {
